@@ -12,12 +12,15 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from gearman import JOB_UNKNOWN
 from libra.common.json_gearman import JSONGearmanClient
 
 
 class GearJobs(object):
     def __init__(self, logger, args):
         self.logger = logger
+        self.poll_timeout = args.poll_timeout
+        self.poll_timeout_retry = args.poll_timeout_retry
         self.gm_client = JSONGearmanClient(args.server)
 
     def send_pings(self, node_list):
@@ -30,10 +33,10 @@ class GearJobs(object):
             list_of_jobs.append(dict(task=str(node), data=job_data))
         submitted_pings = self.gm_client.submit_multiple_jobs(
             list_of_jobs, background=False, wait_until_complete=True,
-            poll_timeout=5.0
+            poll_timeout=self.poll_timeout
         )
         for ping in submitted_pings:
-            if ping.state == 'UNKNOWN':
+            if ping.state == JOB_UNKNOWN:
                 # TODO: Gearman server failed, ignoring for now
                 self.logger.error('Gearman Job server fail')
                 continue
@@ -51,6 +54,7 @@ class GearJobs(object):
                 failed_list.append(ping.job.task)
                 continue
 
+        list_of_jobs = []
         if len(retry_list) > 0:
             self.logger.info(
                 "{0} pings timed out, retrying".format(len(retry_list))
@@ -59,10 +63,10 @@ class GearJobs(object):
                 list_of_jobs.append(dict(task=str(node), data=job_data))
             submitted_pings = self.gm_client.submit_multiple_jobs(
                 list_of_jobs, background=False, wait_until_complete=True,
-                poll_timeout=10.0
+                poll_timeout=self.poll_timeout_retry
             )
             for ping in submitted_pings:
-                if ping.state == 'UNKNOWN':
+                if ping.state == JOB_UNKNOWN:
                     # TODO: Gearman server failed, ignoring for now
                     self.logger.error('Gearman Job server fail')
                     continue
@@ -90,10 +94,10 @@ class GearJobs(object):
             list_of_jobs.append(dict(task=str(node), data=job_data))
         submitted_pings = self.gm_client.submit_multiple_jobs(
             list_of_jobs, background=False, wait_until_complete=True,
-            poll_timeout=5.0
+            poll_timeout=self.poll_timeout
         )
         for ping in submitted_pings:
-            if ping.state == 'UNKNOWN':
+            if ping.state == JOB_UNKNOWN:
                 # TODO: Gearman server failed, ignoring for now
                 self.logger.error('Gearman Job server fail')
                 continue
